Crate rusoto_personalize_events

Crate rusoto_personalize_events 

If you’re using the service, you’re probably looking for PersonalizeEventsClient and PersonalizeEvents.

Structs

Event

Represents user interaction event information sent using the PutEvents API.

PersonalizeEventsClient
A client for the Amazon Personalize Events API.
PutEventsRequest

Enums

PutEventsError
Errors returned by PutEvents

Traits

PersonalizeEvents
Trait representing the capabilities of the Amazon Personalize Events API. Amazon Personalize Events clients implement this trait.